==> haskell-ansi-terminal-0.8.0.4-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-terminal
version: 0.8.0.4
id: ansi-terminal-0.8.0.4-Ll5nsATqQAoCUSOmfm7Ux8
key: ansi-terminal-0.8.0.4-Ll5nsATqQAoCUSOmfm7Ux8
license: BSD-3-Clause
maintainer: Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>
author: Max Bolingbroke
homepage: https://github.com/feuerbach/ansi-terminal
synopsis: Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.
category: User Interfaces
abi: 60434811d26166e1bacacf0138207cc4
exposed: True
exposed-modules:
    System.Console.ANSI System.Console.ANSI.Codes
    System.Console.ANSI.Types
hidden-modules: System.Console.ANSI.Unix
import-dirs: /usr/lib/ghc-8.4.3/site-local/ansi-terminal-0.8.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/ansi-terminal-0.8.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/ansi-terminal-0.8.0.4
hs-libraries: HSansi-terminal-0.8.0.4-Ll5nsATqQAoCUSOmfm7Ux8
depends:
    base-4.11.1.0 colour-2.3.4-LwnsVzimEGhISHXG0rWd9S
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             colour-2.3.4-LwnsVzimEGhISHXG0rWd9S=2d61ca7122d93a5e872724e349398ce5
haddock-interfaces: /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-0.8.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-terminal
version: 0.8.1
id: ansi-terminal-0.8.1-9jw961s99VhJdcOClGpOKt
key: ansi-terminal-0.8.1-9jw961s99VhJdcOClGpOKt
license: BSD-3-Clause
maintainer: Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>
author: Max Bolingbroke
homepage: https://github.com/feuerbach/ansi-terminal
synopsis: Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.
category: User Interfaces
abi: 0f3e70a80d11d230e4e0d22a270bea36
exposed: True
exposed-modules:
    System.Console.ANSI System.Console.ANSI.Codes
    System.Console.ANSI.Types
hidden-modules: System.Console.ANSI.Unix
import-dirs: /usr/lib/ghc-8.6.1/site-local/ansi-terminal-0.8.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/ansi-terminal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/ansi-terminal-0.8.1
hs-libraries: HSansi-terminal-0.8.1-9jw961s99VhJdcOClGpOKt
depends:
    base-4.12.0.0 colour-2.3.4-BYzTQyKoQ9LK29pbkBo2SY
haddock-interfaces: /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
